parallel

package
v0.0.0-...-ac72f74 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddParallelChain

func AddParallelChain[N, I, O any](opts flagutils.OptionSetProvider, c chain.Chain[I, O], a chain.Chain[O, N]) chain.Chain[I, N]

AddParallelChain evaluates the parallel Options (if present) to decide whether chain a should be executed parallel or just added to chain c. This helper can be used, for example, by output implementations to organize their processing chains.

Types

type Options

type Options struct {
	flagutils.SimpleOption[int, *Options]
	// contains filtered or unexported fields
}

func From

func New

func New(n ...int) *Options

func (*Options) Finalize

func (*Options) GetPool

func (o *Options) GetPool() processing.Processing

func (*Options) Validate

func (*Options) WithPoolProvider

func (o *Options) WithPoolProvider(p PoolProvider) *Options

type PoolProvider

type PoolProvider func(ctx context.Context, n int) processing.Processing

Jump to